@@ -7,9 +7,9 @@ use Mojo::Util;
 # Avoid "Subroutine redefined" warnings
 require JSON::Validator;
 
-has enum => sub { +[] };
+has enum                                   => sub { +[] };
 has [qw(format max min multiple_of regex)] => undef;
-has type => 'object';
+has type                                   => 'object';
 
 for my $attr (qw(required strict unique)) {
   Mojo::Util::monkey_patch(__PACKAGE__,
@@ -43,6 +43,8 @@ sub extend {
   my $clone = shift->new(%$self, %$by);
 
   if ($self->type eq 'object') {
+    unshift @{$clone->{required}}, @{$self->{required}}
+      if ref $self->{required} eq 'ARRAY';
     $clone->{properties}{$_} ||= $self->{properties}{$_}
       for keys %{$self->{properties} || {}};
   }
@@ -81,7 +83,8 @@ sub uri       { shift->_type('string')->format('uri') }
 
 sub validate {
   my ($self, $data) = @_;
-  state $jv = JSON::Validator->new->coerce(1);
+  state $jv
+    = JSON::Validator->new->coerce({booleans => 1, numbers => 1, strings => 1});
   return $jv->validate($data, $self->compile);
 }
 
